package javax.script;

import java.util.Collections;
import java.util.ArrayList;
import java.util.List;
import java.util.Iterator;
import java.util.ServiceConfigurationError;
import java.security.AccessController;
import java.security.PrivilegedAction;
import java.util.ServiceLoader;
import java.util.HashMap;
import java.util.HashSet;

public class ScriptEngineManager
{
    private static final boolean DEBUG = false;
    private HashSet<ScriptEngineFactory> engineSpis;
    private HashMap<String, ScriptEngineFactory> nameAssociations;
    private HashMap<String, ScriptEngineFactory> extensionAssociations;
    private HashMap<String, ScriptEngineFactory> mimeTypeAssociations;
    private Bindings globalScope;
    
    public ScriptEngineManager() {
        this.init(Thread.currentThread().getContextClassLoader());
    }
    
    public ScriptEngineManager(ClassLoader classLoader) {
        this.init(classLoader);
    }
    
    private void init(ClassLoader classLoader) {
        this.globalScope = new SimpleBindings();
        this.engineSpis = new HashSet();
        this.nameAssociations = new HashMap();
        this.extensionAssociations = new HashMap();
        this.mimeTypeAssociations = new HashMap();
        this.initEngines(classLoader);
    }
    
    private ServiceLoader<ScriptEngineFactory> getServiceLoader(ClassLoader loader) {
        if (loader != null) {
            return ServiceLoader.load(ScriptEngineFactory.class, loader);
        }
        return ServiceLoader.loadInstalled(ScriptEngineFactory.class);
    }
    
    private void initEngines(final ClassLoader classLoader) {
        Iterator<Object> iterator;
        try {
            iterator = ((ServiceLoader)AccessController.doPrivileged(new PrivilegedAction<ServiceLoader<ScriptEngineFactory>>() {
                @Override
                public ServiceLoader<ScriptEngineFactory> run() {
                    return ScriptEngineManager.access$000(ScriptEngineManager.this, classLoader);
                }
            })).iterator();
        }
        catch (ServiceConfigurationError serviceConfigurationError) {
            System.err.println("Can't find ScriptEngineFactory providers: " + serviceConfigurationError.getMessage());
            return;
        }
        try {
            while (iterator.hasNext()) {
                try {
                    this.engineSpis.add((ScriptEngineFactory)iterator.next());
                }
                catch (ServiceConfigurationError serviceConfigurationError2) {
                    System.err.println("ScriptEngineManager providers.next(): " + serviceConfigurationError2.getMessage());
                }
            }
        }
        catch (ServiceConfigurationError serviceConfigurationError3) {
            System.err.println("ScriptEngineManager providers.hasNext(): " + serviceConfigurationError3.getMessage());
            return;
        }
    }
    
    public void setBindings(Bindings globalScope) {
        if (globalScope == null) {
            throw new IllegalArgumentException("Global scope cannot be null.");
        }
        this.globalScope = globalScope;
        return;
    }
    
    public Bindings getBindings() {
        return this.globalScope;
    }
    
    public void put(String s, Object o) {
        this.globalScope.put(s, o);
    }
    
    public Object get(String s) {
        return this.globalScope.get(s);
    }
    
    public ScriptEngine getEngineByName(String key) {
        if (key == null) {
            throw new NullPointerException();
        }
        Object value;
        if (null != (value = this.nameAssociations.get(key))) {
            ScriptEngineFactory scriptEngineFactory = (ScriptEngineFactory)value;
            try {
                ScriptEngine scriptEngine = scriptEngineFactory.getScriptEngine();
                scriptEngine.setBindings(this.getBindings(), 200);
                return scriptEngine;
            }
            catch (Exception ex) {}
        }
        for (ScriptEngineFactory scriptEngineFactory2 : this.engineSpis) {
            List<String> names = null;
            try {
                names = scriptEngineFactory2.getNames();
            }
            catch (Exception ex2) {}
            if (names != null) {
                Iterator<Object> iterator2 = names.iterator();
                while (iterator2.hasNext()) {
                    if (key.equals((Object)iterator2.next())) {
                        try {
                            ScriptEngine scriptEngine2 = scriptEngineFactory2.getScriptEngine();
                            scriptEngine2.setBindings(this.getBindings(), 200);
                            return scriptEngine2;
                        }
                        catch (Exception ex3) {}
                    }
                    else {
                        continue;
                    }
                }
            }
            else {
                continue;
            }
        }
        return null;
    }
    
    public ScriptEngine getEngineByExtension(String key) {
        if (key == null) {
            throw new NullPointerException();
        }
        Object value;
        if (null != (value = this.extensionAssociations.get(key))) {
            ScriptEngineFactory scriptEngineFactory = (ScriptEngineFactory)value;
            try {
                ScriptEngine scriptEngine = scriptEngineFactory.getScriptEngine();
                scriptEngine.setBindings(this.getBindings(), 200);
                return scriptEngine;
            }
            catch (Exception ex) {}
        }
        for (ScriptEngineFactory scriptEngineFactory2 : this.engineSpis) {
            List<String> extensions = null;
            try {
                extensions = scriptEngineFactory2.getExtensions();
            }
            catch (Exception ex2) {}
            if (extensions == null) {
                continue;
            }
            Iterator<Object> iterator2 = extensions.iterator();
            while (iterator2.hasNext()) {
                if (key.equals((Object)iterator2.next())) {
                    try {
                        ScriptEngine scriptEngine2 = scriptEngineFactory2.getScriptEngine();
                        scriptEngine2.setBindings(this.getBindings(), 200);
                        return scriptEngine2;
                    }
                    catch (Exception ex3) {}
                }
                else {
                    continue;
                }
            }
        }
        return null;
    }
    
    public ScriptEngine getEngineByMimeType(String key) {
        if (key == null) {
            throw new NullPointerException();
        }
        Object value;
        if (null != (value = this.mimeTypeAssociations.get(key))) {
            ScriptEngineFactory scriptEngineFactory = (ScriptEngineFactory)value;
            try {
                ScriptEngine scriptEngine = scriptEngineFactory.getScriptEngine();
                scriptEngine.setBindings(this.getBindings(), 200);
                return scriptEngine;
            }
            catch (Exception ex) {}
        }
        for (ScriptEngineFactory scriptEngineFactory2 : this.engineSpis) {
            List<String> mimeTypes = null;
            try {
                mimeTypes = scriptEngineFactory2.getMimeTypes();
            }
            catch (Exception ex2) {}
            if (mimeTypes == null) {
                continue;
            }
            Iterator<Object> iterator2 = mimeTypes.iterator();
            while (iterator2.hasNext()) {
                if (key.equals((Object)iterator2.next())) {
                    try {
                        ScriptEngine scriptEngine2 = scriptEngineFactory2.getScriptEngine();
                        scriptEngine2.setBindings(this.getBindings(), 200);
                        return scriptEngine2;
                    }
                    catch (Exception ex3) {}
                }
                else {
                    continue;
                }
            }
        }
        return null;
    }
    
    public List<ScriptEngineFactory> getEngineFactories() {
        ArrayList list = new ArrayList(this.engineSpis.size());
        Iterator<ScriptEngineFactory> iterator = this.engineSpis.iterator();
        while (iterator.hasNext()) {
            list.add((E)iterator.next());
        }
        return Collections.unmodifiableList(list);
    }
    
    public void registerEngineName(String key, ScriptEngineFactory value) {
        if (key == null || value == null) {
            throw new NullPointerException();
        }
        this.nameAssociations.put(key, value);
        return;
    }
    
    public void registerEngineMimeType(String key, ScriptEngineFactory value) {
        if (key == null || value == null) {
            throw new NullPointerException();
        }
        this.mimeTypeAssociations.put(key, value);
        return;
    }
    
    public void registerEngineExtension(String key, ScriptEngineFactory value) {
        if (key == null || value == null) {
            throw new NullPointerException();
        }
        this.extensionAssociations.put(key, value);
        return;
    }
    
    static ServiceLoader access$000(ScriptEngineManager scriptEngineManager, ClassLoader classLoader) {
        return scriptEngineManager.getServiceLoader(classLoader);
    }
}
